Crate moonalloy

Crate moonalloy 

moonalloy - A Safe Scientific Computing Library for the 21st-century

moonalloy provides a library structures and implementations for techniques used in the domain of scientific computing/computational science, such as tool for numerical linear algebra. The library leverages rust’s immutability by-default to achieve purity for the mathematical functions.

All the structures and functions are accessible in other languages through the FFI for the C ABI. Lua (Luajit) is a first-class supported language. For frontend wrappers for Lua see moonalloy-luajit.

Modules

linalg
Abstractions for Linear Algebra
machine_learning
Implementations of Machine Learning models

Functions

array_add
FFI-function that adds two arrays together and returns a copy of the result.
array_concat
FFI-function that returns a concatenation of two Arrays.
array_dotp
FFI-function that takes the dot product of two Arrays and returns a copy of the result.
array_mult
FFI-function that multiplies two arrays elements by elements and returns a copy of the result.
array_new
FFI-function that creates a new, empty array.
array_ones
FFI-function that returns an Array of ones.
array_print
FFI-function that prints the contents of an array to stdout.
array_scalar
FFI-function that multiplies the array with a scalar value.
array_sub
FFI-function that subtracts two arrays and returns a copy of the result.
array_sum
FFI-function for calculating the sum of the elements of an array.
array_to_string
FFI-function that returns a string representation of the contents of an Array.
array_zeros
FFI-function that returns an Array of zeros.
linalg_gauss
FFI-function that solves a system of linear equations with Gauss Elimination.
matrix_add
FFI-function that adds two matrices together and returns a copy of the result.
matrix_elem_mult
FFI-function that performs element-wise multiplication of two matrices.
matrix_identity
FFI-function that returns an identity matrix of rank n.
matrix_mult
FFI-function that multiplies two matrices and returns a copy of the result.
matrix_ones
FFI-function that returns a nxm matrix of ones.
matrix_print
FFI-function that prints the contents of a matrix to stdout.
matrix_scalar
FFI-function that multiplies the elements of a matrix with a scalar value.
matrix_sub
FFI-function that subtracts two matrices and returns a copy of the result.
matrix_to_string
FFI-function that returns a string representation of a matrix.
matrix_transpose
FFI-function that transposes a matrix and returns the result as a copy.
matrix_zeros
FFI-function that returns a nxm matrix of zeros.