moonalloy - A Safe Scientific Computing Library for the 21st-century
moonalloy provides a library structures and implementations for techniques used in the
domain of scientific computing/computational science, such as tool for numerical
linear algebra. The library leverages rust’s immutability by-default to achieve purity for
the mathematical functions.
All the structures and functions are accessible in other languages through the FFI for the C
ABI. Lua (Luajit) is a first-class supported language. For frontend wrappers for Lua see
.
Modules
- linalg
- Abstractions for Linear Algebra
- machine_
learning - Implementations of Machine Learning models
Functions
- array_
add - FFI-function that adds two arrays together and returns a copy of the result.
- array_
concat - FFI-function that returns a concatenation of two Arrays.
- array_
dotp - FFI-function that takes the dot product of two Arrays and returns a copy of the result.
- array_
mult - FFI-function that multiplies two arrays elements by elements and returns a copy of the result.
- array_
new - FFI-function that creates a new, empty array.
- array_
ones - FFI-function that returns an Array of ones.
- array_
print - FFI-function that prints the contents of an array to stdout.
- array_
scalar - FFI-function that multiplies the array with a scalar value.
- array_
sub - FFI-function that subtracts two arrays and returns a copy of the result.
- array_
sum - FFI-function for calculating the sum of the elements of an array.
- array_
to_ string - FFI-function that returns a string representation of the contents of an Array.
- array_
zeros - FFI-function that returns an Array of zeros.
- linalg_
gauss - FFI-function that solves a system of linear equations with Gauss Elimination.
- matrix_
add - FFI-function that adds two matrices together and returns a copy of the result.
- matrix_
elem_ mult - FFI-function that performs element-wise multiplication of two matrices.
- matrix_
identity - FFI-function that returns an identity matrix of rank n.
- matrix_
mult - FFI-function that multiplies two matrices and returns a copy of the result.
- matrix_
ones - FFI-function that returns a
nxmmatrix of ones. - matrix_
print - FFI-function that prints the contents of a matrix to stdout.
- matrix_
scalar - FFI-function that multiplies the elements of a matrix with a scalar value.
- matrix_
sub - FFI-function that subtracts two matrices and returns a copy of the result.
- matrix_
to_ string - FFI-function that returns a string representation of a matrix.
- matrix_
transpose - FFI-function that transposes a matrix and returns the result as a copy.
- matrix_
zeros - FFI-function that returns a
nxmmatrix of zeros.